@@ -69,18 +69,25 @@ sub select {
     my ($self, %args) = @_;
     my ($stmt, @bind, @fields);
 
-    @fields= ref($args{fields}) eq 'ARRAY' ? @{$args{fields}} : split /\s+/, $args{fields};
-
+    if (exists $args{fields}) {
+	@fields= ref($args{fields}) eq 'ARRAY' ? @{$args{fields}} : split /\s+/, $args{fields};
+    }
+    else {
+	@fields = ('*');
+    }
+    
     if ($args{join}) {
 	my @join = ref($args{join}) eq 'ARRAY' ? @{$args{join}} : split /\s+/, $args{join};
 
 	# extended syntax for a join
 	($stmt, @bind) = $self->{sqla}->select(-columns => \@fields,
 					       -from => [-join => @join], 
-					       -where => $args{where});
+					       -where => $args{where},
+					       -order_by => $args{order},
+	    				      );
     }
     else {
-	($stmt, @bind) = $self->{sqla}->select($args{table}, \@fields, $args{where});
+	($stmt, @bind) = $self->{sqla}->select($args{table}, \@fields, $args{where}, $args{order});
     }
 
     return $self->_run($stmt, \@bind, %args);
